from setuptools import setup, find_packages  # type: ignore

setup(name='full-month',
      version='0.0.3',
      description='show the full display of one month of 5 row * 7 day format,starting from Monday and ending on Sunday.',
      author='neomaple',
      author_email='xinkun7778@163.com',
      license='None',
      packages=find_packages())
